@@ -34,7 +34,7 @@ Version 2.4.2
 
 =cut
 
-our $VERSION = '2.47';
+our $VERSION = '2.48';
 
 =head1 SYNOPSIS
 
@@ -86,7 +86,6 @@ has 'outdir' => (
     isa => 'Str',
     required => 1,
     default => sub {return getcwd()."/logs" },
-    #    default => sub { return "$ENV{HOME}/hpcjobs" },
     documentation => q{Directory to write out files.},
     trigger => \&_set_outdir,
 );
@@ -134,44 +133,7 @@ has 'procs' => (
     documentation => q{Total number of running jobs allowed at any time. The command 'wait' can be used to have a variable number of children running.}
 );
 
-=head2 job_scheduler_id
-
-Job Scheduler ID running the script. Passed to slurm for mail information
-
-=cut
-
-has 'job_scheduler_id' => (
-    is => 'rw',
-    isa => 'Str|Undef',
-    default => sub { return $ENV{SBATCH_JOB_ID} || $ENV{PBS_JOBID} || undef; },
-    required => 1,
-    documentation => q{This defaults to your current Job Scheduler ID. Ignore this if running on a single node},
-    predicate => 'has_job_scheduler_id',
-    clearer => 'clear_job_scheduler_id',
-);
-
-=head2 jobname
-
-Specify a job name, and jobs will be jobname_1, jobname_2, jobname_x
-
-=cut
-
-has 'jobname' => (
-    is => 'rw',
-    isa => 'Str',
-    required => 0,
-    traits  => ['String'],
-    default => q{job},
-    default => sub { return $ENV{SBATCH_JOB_NAME} || $ENV{PBS_JOBNAME} || 'job'; },
-    predicate => 'has_jobname',
-    handles => {
-        add_jobname => 'append',
-        clear_jobname => 'clear',
-        replace_jobname => 'replace',
-    },
-    documentation => q{Specify a job name, each job will be appended with its batch order},
-);
-
+#TODO add to Log
 has 'show_processid' => (
     is => 'rw',
     isa => 'Bool',
@@ -179,6 +141,7 @@ has 'show_processid' => (
     documentation => q{Show the process ID per logging message. This is useful when aggregating logs.}
 );
 
+#TODO add to Log
 has 'metastr' => (
     is => 'rw',
     isa => 'Str',
@@ -194,25 +157,13 @@ You shouldn't be calling these directly.
 =cut
 
 has 'dt' => (
+    traits  => ['NoGetopt'],
     is => 'rw',
     isa => 'DateTime',
     default => sub { return DateTime->now(time_zone => 'local'); },
     lazy => 1,
 );
 
-=head2 jobref
-
-Array of arrays details slurm/process/scheduler job id. Index -1 is the most recent job submissisions, and there will be an index -2 if there are any job dependencies
-
-=cut
-
-has 'jobref' => (
-    traits  => ['NoGetopt'],
-    is => 'rw',
-    isa => 'ArrayRef',
-    default => sub { [ [] ]  },
-);
-
 =head2 wait
 
 Boolean value indicates any job dependencies
@@ -316,6 +267,19 @@ has 'plugins' => (
     documentation => 'Add Plugins to your run',
 );
 
+=head2 jobref
+
+Array of arrays details slurm/process/scheduler job id. Index -1 is the most recent job submissisions, and there will be an index -2 if there are any job dependencies
+
+=cut
+
+has 'jobref' => (
+    traits  => ['NoGetopt'],
+    is => 'rw',
+    isa => 'ArrayRef',
+    default => sub { [ [] ]  },
+);
+
 =head1 Subroutines
 
 =cut
@@ -512,6 +476,7 @@ sub log_table {
 EOF
 }
 
+#This should be run_job instead and in main app
 sub log_job {
     my $self = shift;
 
